@@ -49,11 +49,15 @@ unset SPLASHPNG         || true
 unset OMIT_MANUAL	 || true
 unset OMIT_RELEASE_NOTES || true
 unset OMIT_DOC_TOOLS     || true
+unset MAX_PKG_SIZE       || true
 
 # The debian-cd dir
 # Where I am (hoping I'm in the debian-cd dir)
 export BASEDIR=`pwd`
 
+# Name of the distribution for the image filename (Defaults to 'debian')
+# export CDNAME=debian
+
 # Building squeeze cd set ...
 export CODENAME=squeeze
 
@@ -124,6 +128,11 @@ export CONTRIB=1
 # WARNING: Don't use NONFREE and EXTRANONFREE at the same time !
 # export EXTRANONFREE=1
 
+# Do I want to force (potentially non-free) firmware packages to be
+# placed on disc 1? Will make installation much easier if systems
+# contain hardware that depends on this firmware
+# export FORCE_FIRMWARE=1
+
 # If you have a $MIRROR/dists/$CODENAME/local/binary-$ARCH dir with 
 # local packages that you want to put on the CD set then
 # uncomment the following line 
@@ -166,8 +175,14 @@ export ISOLINUX=1
 # uncomment this to if you want to see more of what the Makefile is doing
 #export VERBOSE_MAKE=1
 
-# uncoment this to make build_all.sh try to build a simple CD image if
-# the proper official CD run does not work
+# The maximum size allowed for an individual package, in bytes; if
+# larger than this, it will be excluded (and all dependents, of
+# course). We'll create a README.excluded in the root of CD1 listing
+# them too
+export MAX_PKG_SIZE=600000000
+
+# Should build_all.sh try to build a simple CD image if the proper official
+# CD run does not work?
 ATTEMPT_FALLBACK=yes
 
 # Set your disk type here. Known types are:
@@ -189,6 +204,9 @@ export DISKTYPE=CD
 # included. See tasks/README.tasksel for further info.
 export TASK_LANGLIST=tasksel_d-i.languages
 
+# Extra variants to enable. See docs/README.variants for more information.
+export VARIANTS=
+
 # We don't want certain packages to take up space on CD1...
 #export EXCLUDE1=exclude
 # ...but they are okay for other CDs (UNEXCLUDEx == may be included
@@ -198,16 +216,20 @@ export TASK_LANGLIST=tasksel_d-i.languages
 # excluded completely. The same goes for packages listed in EXCLUDE.
 
 # Set this if the recommended packages should be skipped when adding 
-# package on the CD.  The default is 'false'.
-export NORECOMMENDS=1
+# package on the CD.  The default is 'true'.
+# export NORECOMMENDS=1
 
 # Set this if the suggested packages should be skipped when adding 
 # package on the CD.  The default is 'true'.
-#export NOSUGGESTS=1
+# export NOSUGGESTS=1
 
-# Set to 1 to generate MD5 and SHA1 sums for generated images
+# Set to 1 to generate MD5/SHA1/SHA256/SHA512 sums for generated images
 export IMAGESUMS=1
 
+# And define the set of checksum algorithms you want here. Default is
+# all of: md5 sha1 sha512 sha256
+# export CHECKSUMS="md5 sha1 sha512 sha256"
+
 # We may have to extract files from packages to put them onto the CD
 # (e.g. bootloader files). If you make those packages (and their
 # sources) available somewhere, list it here so that README.source
@@ -217,7 +239,7 @@ export ARCHIVE_EXTRACTED_SOURCES="http://cdimage.debian.org/cdimage/cd-sources/"
 # Produce iso/jigdo files: specify how many iso/jigdo files should be
 # produced in your set. If not set or when the value is "ALL" they will
 # be created for all images. One of the variables can be set to zero if
-# either iso or jigdo files are not wanted, but not both.
+# either iso or jigdo files are not wanted.
 # Replaces the old "DOJIGDO" setting with something much more flexible.
 #export MAXISOS=0
 #export MAXJIGDOS=0
@@ -320,7 +342,8 @@ done
 # Default desktop (currently only used by win32-loader)
 #export DESKTOP=kde
 
-# If set, limits the number of binary CDs to produce.
+# If set, limits the number of images to produce. The maximum
+# value of MAXISOS and MAXJIGDOS are limited to this setting.
 #export MAXCDS=1
 
 # If set, overrides the boot picture used.
@@ -334,14 +357,14 @@ done
 # If so we will link to them on the web site.
 export OMIT_RELEASE_NOTES=1
 
+# Set this to override the default location
+#export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/$CODENAME"
+
 # Set to 1 to not include the doc/tools directories on CD1
 # Useful to save space and avoids failures if you have a mirror
 # without those directories.
 #export OMIT_DOC_TOOLS=1
 
-# Set this to override the default location
-#export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/$CODENAME"
-
 case "$OFFICIAL" in
     "Official")
 	export OFFICIAL_VAL=2
